@@ -7,12 +7,12 @@ from typing import Union, Dict, Any, Tuple, Optional, List, cast
 import astropy.units as u
 from astropy.io import fits
 
-from pyobs.comm import TimeoutException, InvocationException, RemoteException
+from pyobs.comm import TimeoutException
 from pyobs.images import Image
 from pyobs.interfaces import IFitsHeaderBefore, IFitsHeaderAfter
 from pyobs.modules import Module
 from pyobs.utils.fits import format_filename
-from pyobs.utils.parallel import Future
+from pyobs.utils import exceptions as exc
 from pyobs.utils.time import Time
 
 log = logging.getLogger(__name__)
@@ -28,6 +28,8 @@ class FitsHeaderMixin:
         fits_namespaces: Optional[List[str]] = None,
         fits_headers: Optional[Dict[str, Any]] = None,
         filenames: str = "/cache/pyobs-{DAY-OBS|date:}-{FRAMENUM|string:04d}.fits",
+        frame_number: bool = True,
+        night_obs: bool = False,
         **kwargs: Any,
     ):
         """Initialise the mixin.
@@ -36,6 +38,8 @@ class FitsHeaderMixin:
             fits_namespaces: List of namespaces for FITS headers that this camera should request.
             fits_headers: Additional FITS headers.
             filename: Filename pattern for FITS images.
+            frame_number: Whether to add frame number to FITS file header.
+            night_obs: If True, DAY-OBS will contain the night of observation, not the calendar day.
         """
         module = cast(Module, self)
 
@@ -45,10 +49,12 @@ class FitsHeaderMixin:
         self._fitsheadermixin_fits_headers = fits_headers if fits_headers is not None else {}
         if "OBSERVER" not in self._fitsheadermixin_fits_headers:
             self._fitsheadermixin_fits_headers["OBSERVER"] = ["pyobs", "Name of observer"]
+        self._fitsheadermixin_night_obs = night_obs
 
         # night exposure number
         self._fitsheadermixin_cache = "/pyobs/modules/%s/cache.yaml" % module.name()
-        self._fitsheadermixin_frame_num = 0
+        self._fitsheadermixin_enable_frame_number = frame_number
+        self._fitsheadermixin_frame_number = 0
 
     async def request_fits_headers(self, before: bool = True) -> Dict[str, Coroutine]:
         """Request FITS headers from other modules.
@@ -95,14 +101,8 @@ class FitsHeaderMixin:
             log.info("Fetching FITS headers from %s...", client)
             try:
                 headers = await future
-            except TimeoutException:
-                log.warning("Fetching FITS headers from %s timed out.", client)
-                continue
-            except InvocationException as e:
-                log.warning("Could not fetch FITS headers from %s: %s.", client, e.get_message())
-                continue
-            except RemoteException as e:
-                log.warning("Could not fetch FITS headers from %s: %s.", client, e.get_message())
+            except exc.RemoteError as e:
+                log.warning("Could not fetch FITS headers from %s: %s.", client, str(e))
                 continue
 
             # add them to fits file
@@ -132,7 +132,8 @@ class FitsHeaderMixin:
 
         # add more fits headers
         self._fitsheadermixin_add_fits_headers(image)
-        await self._fitsheadermixin_add_framenum(image)
+        if self._fitsheadermixin_enable_frame_number:
+            await self._fitsheadermixin_add_framenum(image)
 
     def _fitsheadermixin_add_fits_headers(self, image: Union[Image, fits.PrimaryHDU]) -> None:
         """Add FITS header keywords to the given FITS header.
@@ -173,7 +174,10 @@ class FitsHeaderMixin:
                 hdr["LST"] = (lst.to_string(unit=u.hour, sep=":"), "Local sidereal time")
 
         # date of night this observation is in
-        hdr["DAY-OBS"] = (date_obs.night_obs(module.observer).strftime("%Y-%m-%d"), "Night of observation")
+        if self._fitsheadermixin_night_obs:
+            hdr["DAY-OBS"] = (date_obs.night_obs(module.observer).strftime("%Y-%m-%d"), "Night of observation")
+        else:
+            hdr["DAY-OBS"] = (date_obs.strftime("%Y-%m-%d"), "Day of observation")
 
     async def _fitsheadermixin_add_framenum(self, image: Union[Image, fits.PrimaryHDU]) -> None:
         """Add FRAMENUM keyword to header
@@ -190,7 +194,7 @@ class FitsHeaderMixin:
         night = hdr["DAY-OBS"]
 
         # increase night exp
-        self._fitsheadermixin_frame_num += 1
+        self._fitsheadermixin_frame_number += 1
 
         # do we have a cache?
         if self._fitsheadermixin_cache is not None:
@@ -201,11 +205,11 @@ class FitsHeaderMixin:
 
                 # get new number
                 if cache is not None and "framenum" in cache:
-                    self._fitsheadermixin_frame_num = cache["framenum"] + 1
+                    self._fitsheadermixin_frame_number = cache["framenum"] + 1
 
                 # if nights differ, reset count
                 if cache is not None and "night" in cache and night != cache["night"]:
-                    self._fitsheadermixin_frame_num = 1
+                    self._fitsheadermixin_frame_number = 1
 
             except (FileNotFoundError, ValueError):
                 pass
@@ -213,13 +217,13 @@ class FitsHeaderMixin:
             # write file
             try:
                 await module.vfs.write_yaml(
-                    self._fitsheadermixin_cache, {"night": night, "framenum": self._fitsheadermixin_frame_num}
+                    self._fitsheadermixin_cache, {"night": night, "framenum": self._fitsheadermixin_frame_number}
                 )
             except (FileNotFoundError, ValueError):
                 log.warning("Could not write camera cache file.")
 
         # set it
-        hdr["FRAMENUM"] = self._fitsheadermixin_frame_num
+        hdr["FRAMENUM"] = self._fitsheadermixin_frame_number
 
     def format_filename(self, image: Union[Image, fits.PrimaryHDU]) -> Optional[str]:
         """Format filename according to given pattern and store in header of image.
